/***************************************************************************
                          susehwitem.h  -  description
                             -------------------
    copyright            : (C) 2002 SuSE AG 
    email                : Oliver.Ries@suse.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SUSEHWITEM_H
#define SUSEHWITEM_H

#include <stdlib.h>
#include <stdio.h>
#include <hd.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qwidget.h>
#include <qmap.h>
#include <qcstring.h>
#include <qfile.h>
#include <qthread.h>
#include <kconfig.h>
#include <kprocess.h>
#include <kdirwatch.h>

#include "susehwpopup.h"
#include "susemediapopup.h"
#include "defines.h"

typedef struct {
bool enableHdd;
bool enableCam;
bool enableFloppy;
bool enableCdrom;
bool enableZip;
bool enableHotplug;
}feat;

class CDreadThread : public QThread
{
public:
	CDreadThread( QObject *parent, const QString &device );
	~CDreadThread();
	virtual void run();
private:
	QString device;
	QObject *parent;
	int     fd;
};

class SuSEhwItem : QObject 
{
Q_OBJECT
public: 
	SuSEhwItem(QObject *par, hd_t *data, KConfig *conf);
	~SuSEhwItem();
	void 		refresh(hd_t *p);
	QString 	getBaseName();
	QString 	getUID();
	void 		setBaseName(QString fn);
	void		newHardwarePopup();
	void 		insertSubClass(QString key, QString data);
	void		insertFileToWatch(QString file);
	hd_status_t	getStatus();
	bool            evaluateFeatures();
	bool		useAutoStart();
	void 		startPoll( );
	bool 		event( QEvent *evt );

private:
	bool		disableCheckForMedia;
	bool		m_useAutoStart;
	int		m_pollIntervall;
	bool 		m_useMediaDetect;
	void 		detectMedia();
	void		handleEvent( const QString &key, const QString &title, const QString &icon );
	void		handleEventAction( QString command, const QString &title, const QString &icon );
	void 		inithd(hd_t *data);
	void		init(KConfig *conf);
	void		readConfig();
	QString		findDevInFstab(QString searchdev);
	bool 		hasBinary(QString fn);
	QString		getTypeString();
	void 		evaluatePopupCombo();
	void 		popupDialog();	

	int 		fd;
	bool		m_mediaCD;
	QString		m_movedToCache;
	QString		checkForMediaType(const QString&);
	bool		m_procRunning;
	bool		myDebug;
	KProcess	*m_proc;
	int		size;	
	int		waitForMountpointCounter;	
	QObject 	*parent;
	bool 		hotplugflag;
	bool		configurable();
	QString         giveRealName(const QString &device);
	SuSEHWPopup1 	*pop1;
	SuSEMediaPopup 	*mediaDialog;
        bool 		positivedestruction;
	QMap<QString, QString> 	subClass;
	KDirWatch	*dirwatch;
	feat 		enableFeatures;

	/***	the hd_t members	***/
	unsigned 	bus_id;
	QString 	bus_name;
	QString		checkforMountPoints(const QString &device);
	bool 		checkifvalidMountPoint(const QString &mp, const QString &opt);

	
	unsigned	slot;			//Slot and bus number
	
	unsigned	func;			//(PCI) function
	
	unsigned	base_class_id;		
	QString 	base_class_name;
	unsigned        sub_class;
        QString		sub_class_name;
	unsigned 	prog_if;
	QString		prog_if_name;
	QString		serial;
	hd_hw_item_t	hw_class;
	QString		type;			// i18n translation of hw_class	
	QString 	model;
	QString		unix_dev_name;
	QString		unique_id;
	hd_status_t 	status;	
	QString 	config_string;
	hd_hotplug_t	hotplug;
	QString		driver;
	bool		hotplug_configured;

	/*	misc		*/
	QString		conf_exec;		// what to run for configuration
	QString		exec;			// what app to run (e.g yawtv for webcam)
	QString		m_CDtype;
	bool		show_popup;
	bool		pollMode;
	KConfig		*config;
	QString		pixmap;			// string which holds iconname
	QString 	baseName;
	
	int 		m_db_level;

	CDreadThread	*deviceThread;

signals:

        void 		queueDialogforPopup(SuSEhwItem *p);
        void 		queuedDialogDone(SuSEhwItem *p, bool show);
        void 		deleteItem(SuSEhwItem *p);
	void		killMe(QString);
	void 		redoItem(QString);

public slots:
	void slotLaunchConfig();
        void slotLaunch();
        void slotConfigToolDone();
	void slotApplicationFinished();
	void checkForMedia();
	void runCommand();

	void plugin();
	void plugout();
        void slotPopupYes();
        void slotPopupNo();
        void slotPopupCancel();

	void slotMediaYes();
	void slotMediaNo();
	void slotMediaCancel();
};
#endif
